package
Version:
v0.0.0-...-dae3534
Opens a new window with list of versions in this module.
Published: May 25, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type AddCacheReq struct {
Key string `json:"key"`
Value string `json:"value"`
}
type CreateTableReq struct {
Name string `json:"name"`
ExpireTime time.Duration `json:"expireTime"`
}
type UpdateCacheReq struct {
Name string `json:"name"`
Key string `json:"key"`
Value string `json:"value"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.